@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.8";
+        "11.0.10";
 
     private static final String java_version_date =
-        "2020-07-14";
+        "2021-01-19";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.8+10-1";
+        "11.0.10+9-1";
 
     private static final String VERSION_NUMBER =
-        "11.0.8";
+        "11.0.10";
 
     private static final String VERSION_BUILD =
-        "10";
+        "9";
 
     private static final String VERSION_PRE =
         "";
@@ -65,7 +65,7 @@ class VersionProps {
         "1".startsWith("LTS");
 
     private static final String VENDOR =
-        "N/A";
+        "Oracle Corporation";
 
     private static final String VENDOR_URL =
         "https://openjdk.java.net/";
