@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -718,6 +718,14 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "egyezm\u00e9nyes koordin\u00e1lt vil\u00e1gid\u0151",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "mauritiusi t\u00e9li id\u0151",
                "",
@@ -1265,16 +1273,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Phoenix" },
             { "timezone.excity.Asia/Katmandu", "Katmandu" },
@@ -1302,6 +1301,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Vosztok" },
             { "America/Panama", America_Eastern },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah, \u00c9szak-Dakota" },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fidzsi" },
             { "timezone.excity.Europe/Gibraltar", "Gibralt\u00e1r" },
             { "Europe/Jersey", GMT },
@@ -1322,6 +1322,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Truk", "Truk" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "America/Argentina/Salta", Argentina },
@@ -1510,6 +1511,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Conakry" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1531,6 +1533,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mahe" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Man-sziget" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
@@ -1539,6 +1542,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "Guyana" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "P\u00e1rizs" },
             { "timezone.excity.Europe/Zagreb", "Z\u00e1gr\u00e1b" },
@@ -1556,16 +1560,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "Csita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Rankin Inlet" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santarem" },
             { "timezone.excity.Asia/Tomsk", "Tomszk" },
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
@@ -1650,17 +1644,8 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1681,6 +1666,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azori-szigetek" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "America/Montreal", America_Eastern },
@@ -1708,6 +1694,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Regina" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1731,16 +1718,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "egyezm\u00e9nyes koordin\u00e1lt vil\u00e1gid\u0151",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "Chisinau" },
             { "timezone.excity.America/Moncton", "Moncton" },
             { "Asia/Singapore", Singapore },
@@ -1795,6 +1773,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "H\u00fasv\u00e9t-szigetek" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1821,6 +1800,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Creston" },
             { "timezone.excity.Africa/Cairo", "Kair\u00f3" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "Vars\u00f3" },
             { "Europe/Skopje", Europe_Central },
@@ -1830,16 +1810,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1876,16 +1846,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Port_of_Spain", Atlantic },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1897,6 +1857,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Szimferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgogr\u00e1d" },
             { "timezone.excity.Europe/Monaco", "Monaco" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1918,6 +1879,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1959,11 +1921,13 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho Si Minh-v\u00e1ros" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makasar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Jekatyerinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "Sz\u00f3fia" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1976,6 +1940,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Kalkutta" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "G\u00e1za" },
             { "timezone.excity.Africa/Ceuta", "Ceuta" },
             { "Africa/Libreville", Africa_Western },
@@ -1985,6 +1950,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "America/Tijuana", America_Pacific },
@@ -2002,6 +1968,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozsje" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -2012,17 +1979,8 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "Chatham-szigetek" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
@@ -2040,6 +1998,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Cambridge_Bay", "Cambridge Bay" },
@@ -2059,6 +2018,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Sydney", "Sydney" },
             { "timezone.excity.Asia/Qatar", "Katar" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2111,6 +2071,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
             { "Asia/Kamchatka", Kamchatka },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Szamarkand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Australia/Adelaide", "Adelaide" },
@@ -2158,30 +2119,10 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
@@ -2189,16 +2130,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.Asia/Kabul", "Kabul" },
