@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -150,6 +150,14 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Africa_Southern = new String[] {
                "S\u00f6d-Affrekaanesche Zigg",
                "",
@@ -187,16 +195,7 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "GMT", GMT },
             { "Africa/Casablanca", Europe_Western },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Indian/Mahe", Seychelles },
             { "timezone.excity.Asia/Gaza", "Jaasa" },
             { "timezone.excity.Asia/Aqtobe", "Aqt\u00f6be" },
@@ -239,6 +238,7 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zaporozhye", "Saporischschja" },
             { "timezone.excity.Asia/Tashkent", "Taschkent" },
             { "timezone.excity.Europe/Zagreb", "Sagreb" },
+            { "ART", Europe_Eastern },
             { "Atlantic/Reykjavik", GMT },
             { "timezone.excity.America/Indiana/Vevay", "Vevay en Indiana" },
             { "Europe/Zaporozhye", Europe_Eastern },
@@ -250,29 +250,9 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Dushanbe", "Duschanbe" },
             { "Europe/Guernsey", GMT },
             { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "Africa/Kigali", Africa_Central },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Isle_of_Man", GMT },
             { "timezone.excity.America/Yakutat", "Jakutat" },
             { "timezone.excity.Pacific/Guam", "Juam" },
@@ -338,16 +318,6 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Maseru", Africa_Southern },
             { "Europe/Gibraltar", Europe_Central },
             { "timezone.excity.Africa/Windhoek", "Windhuk" },
@@ -382,16 +352,6 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Antarctica/DumontDUrville", "Dumont-d\u2019Urville-Schtazjohn" },
             { "Africa/Harare", Africa_Central },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "Europe/Tallinn", Europe_Eastern },
@@ -402,22 +362,13 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "timezone.excity.America/Guayaquil", "Juayaquil" },
             { "Africa/Ndjamena", Africa_Western },
             { "timezone.excity.America/St_Vincent", "Zint Vintsch\u00e4nt" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "timezone.excity.Asia/Singapore", "Singjapuur" },
             { "Europe/Belgrade", Europe_Central },
             { "timezone.excity.Europe/Vienna", "Wien" },
             { "Africa/Bissau", GMT },
             { "timezone.excity.Asia/Nicosia", "Nikosija" },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Europe/Volgograd", "Woljojrad" },
             { "timezone.excity.Asia/Phnom_Penh", "Pnom Penh" },
             { "timezone.excity.Europe/Rome", "Rom" },
@@ -438,6 +389,7 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Europe/Prague", Europe_Central },
             { "Antarctica/Troll", GMT },
             { "timezone.excity.Europe/Zurich", "Z\u00fcresch" },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azoore" },
             { "timezone.excity.Asia/Ashgabat", "Asshgabat" },
             { "timezone.excity.Pacific/Honolulu", "Honululu" },
@@ -448,16 +400,6 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Etc/Unknown", "- we\u00dfe mer nit -" },
             { "Atlantic/Faeroe", Europe_Western },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Riyadh", "Rijad" },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
@@ -467,16 +409,7 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.Europe/Uzhgorod", "Uschjorod" },
             { "timezone.excity.Asia/Damascus", "Damaskus" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "CAT", Africa_Central },
             { "Europe/Tirane", Europe_Central },
             { "Arctic/Longyearbyen", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
@@ -485,16 +418,6 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Africa/Monrovia", GMT },
             { "timezone.excity.America/St_Kitts", "Zint Kitts" },
             { "timezone.excity.Europe/Kaliningrad", "Kalinninjraad" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Pacific/Galapagos", "Jalappajos" },
             { "timezone.excity.Europe/Tirane", "Tiraana" },
             { "timezone.excity.Europe/Prague", "Prag" },
